@@ -6,7 +6,7 @@ use diagnostics;
 use mro 'c3';
 use English;
 use Carp qw[carp croak confess cluck longmess shortmess];
-our $VERSION = 0.4;
+our $VERSION = 0.5;
 use autodie qw( close );
 use Array::Contains;
 use utf8;
@@ -83,12 +83,15 @@ use constant {
 use constant {
     PEP_TRANSACTION_TYPE_GOODS_PAYMENT          => 11,
     PEP_TRANSACTION_TYPE_VOID_GOODS_PAYMENT     => 12,
+    PEP_TRANSACTION_TYPE_GOODS_PAYMENT_WITH_TIP => 13,
     PEP_TRANSACTION_TYPE_CREDIT                 => 41,
     PEP_TRANSACTION_TYPE_RESERVATION            => 51,
     PEP_TRANSACTION_TYPE_BOOK_RESERVATION       => 52,
     PEP_TRANSACTION_TYPE_CANCEL_RESERVATION     => 53,
     PEP_TRANSACTION_TYPE_VOID_RESERVATION       => 54,
     PEP_TRANSACTION_TYPE_VOID_BOOK_RESERVATION  => 55,
+    PEP_TRANSACTION_TYPE_TIP_ONLY_PAYMENT       => 61,
+    PEP_TRANSACTION_TYPE_VOID_TIP_ONLY_PAYMENT  => 62,
 };
 
 ###############################################################################
@@ -226,6 +229,7 @@ use constant {
     PEP_PAYMENT_MODE_UNDEFINED         => 0,
     PEP_PAYMENT_MODE_CARD_PRESENT      => 1,
     PEP_PAYMENT_MODE_CARD_NOT_PRESENT  => 2,
+    PEP_PAYMENT_MODE_TIPPABLE          => 3,  # Enables tip/gratuity dialog on terminal
 };
 
 ###############################################################################
@@ -407,6 +411,7 @@ use constant {
 use constant {
     PEP_TERMINAL_TYPE_GENERIC_ZVT  => 118,
     PEP_TERMINAL_TYPE_HOBEX_ZVT    => 120,
+    PEP_TERMINAL_TYPE_GLOBALPAYMENTS_ZVT  => 129,
     PEP_TERMINAL_TYPE_MOCK         => 999,
 };
 
@@ -464,12 +469,15 @@ our @EXPORT_OK = qw(
 
     PEP_TRANSACTION_TYPE_GOODS_PAYMENT
     PEP_TRANSACTION_TYPE_VOID_GOODS_PAYMENT
+    PEP_TRANSACTION_TYPE_GOODS_PAYMENT_WITH_TIP
     PEP_TRANSACTION_TYPE_CREDIT
     PEP_TRANSACTION_TYPE_RESERVATION
     PEP_TRANSACTION_TYPE_BOOK_RESERVATION
     PEP_TRANSACTION_TYPE_CANCEL_RESERVATION
     PEP_TRANSACTION_TYPE_VOID_RESERVATION
     PEP_TRANSACTION_TYPE_VOID_BOOK_RESERVATION
+    PEP_TRANSACTION_TYPE_TIP_ONLY_PAYMENT
+    PEP_TRANSACTION_TYPE_VOID_TIP_ONLY_PAYMENT
 
     PEP_CALLBACK_EVENT_OUTPUT
     PEP_CALLBACK_EVENT_INPUT
@@ -556,6 +564,7 @@ our @EXPORT_OK = qw(
     PEP_PAYMENT_MODE_UNDEFINED
     PEP_PAYMENT_MODE_CARD_PRESENT
     PEP_PAYMENT_MODE_CARD_NOT_PRESENT
+    PEP_PAYMENT_MODE_TIPPABLE
 
     PEP_PROTOCOL_VERSION_UNDEFINED
     PEP_PROTOCOL_VERSION_ZVT
@@ -662,6 +671,7 @@ our @EXPORT_OK = qw(
 
     PEP_TERMINAL_TYPE_GENERIC_ZVT
     PEP_TERMINAL_TYPE_HOBEX_ZVT
+    PEP_TERMINAL_TYPE_GLOBALPAYMENTS_ZVT
     PEP_TERMINAL_TYPE_MOCK
 );
 
@@ -827,6 +837,7 @@ Terminal type constants
 
     PEP_TERMINAL_TYPE_GENERIC_ZVT (118) - Generic ZVT protocol
     PEP_TERMINAL_TYPE_HOBEX_ZVT (120) - Hobex ZVT protocol
+    PEP_TERMINAL_TYPE_GLOBALPAYMENTS_ZVT (129) - Global Payments ZVT protocol
     PEP_TERMINAL_TYPE_MOCK (999) - Mock implementation for testing
 
 =head1 WARNING: AI USE
